@@ -37,19 +37,21 @@ type Library interface {
 }
 
 type libraryService struct {
-	ds      model.DataStore
-	scanner model.Scanner
-	watcher Watcher
-	broker  events.Broker
+	ds            model.DataStore
+	scanner       model.Scanner
+	watcher       Watcher
+	broker        events.Broker
+	pluginManager PluginUnloader
 }
 
 // NewLibrary creates a new Library service
-func NewLibrary(ds model.DataStore, scanner model.Scanner, watcher Watcher, broker events.Broker) Library {
+func NewLibrary(ds model.DataStore, scanner model.Scanner, watcher Watcher, broker events.Broker, pluginManager PluginUnloader) Library {
 	return &libraryService{
-		ds:      ds,
-		scanner: scanner,
-		watcher: watcher,
-		broker:  broker,
+		ds:            ds,
+		scanner:       scanner,
+		watcher:       watcher,
+		broker:        broker,
+		pluginManager: pluginManager,
 	}
 }
 
@@ -141,6 +143,7 @@ func (s *libraryService) NewRepository(ctx context.Context) rest.Repository {
 		scanner:           s.scanner,
 		watcher:           s.watcher,
 		broker:            s.broker,
+		pluginManager:     s.pluginManager,
 	}
 	return wrapper
 }
@@ -148,11 +151,12 @@ func (s *libraryService) NewRepository(ctx context.Context) rest.Repository {
 type libraryRepositoryWrapper struct {
 	rest.Repository
 	model.LibraryRepository
-	ctx     context.Context
-	ds      model.DataStore
-	scanner model.Scanner
-	watcher Watcher
-	broker  events.Broker
+	ctx           context.Context
+	ds            model.DataStore
+	scanner       model.Scanner
+	watcher       Watcher
+	broker        events.Broker
+	pluginManager PluginUnloader
 }
 
 func (r *libraryRepositoryWrapper) Save(entity interface{}) (string, error) {
@@ -272,6 +276,10 @@ func (r *libraryRepositoryWrapper) Delete(id string) error {
 		log.Debug(r.ctx, "Library deleted - sent refresh event", "libraryID", libID, "name", lib.Name)
 	}
 
+	// After successful deletion, check if any plugins were auto-disabled
+	// and need to be unloaded from memory
+	r.pluginManager.UnloadDisabledPlugins(r.ctx)
+
 	return nil
 }
 
