@@ -5,12 +5,12 @@ import (
 	"encoding/binary"
 	"math/big"
 
-	"golang.org/x/exp/constraints"
+	"github.com/navidrome/navidrome/utils/number"
 )
 
 // Int64N returns a random int64 between 0 and max.
 // This is a reimplementation of math/rand/v2.Int64N using a cryptographically secure random number generator.
-func Int64N[T constraints.Integer](max T) int64 {
+func Int64N[T number.Integer](max T) int64 {
 	rnd, _ := rand.Int(rand.Reader, big.NewInt(int64(max)))
 	return rnd.Int64()
 }
